@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,7 +24,7 @@ class CaptchaOperDataInterceptUnit(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DateKey: 时间
         :type DateKey: str
         :param AllStopCnt: 停止验证数量
@@ -50,7 +50,7 @@ class CaptchaOperDataInterceptUnit(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -60,7 +60,7 @@ class CaptchaOperDataLoadTimeUnit(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DateKey: 时间
         :type DateKey: str
         :param MarketLoadTime: Market加载时间
@@ -82,7 +82,7 @@ class CaptchaOperDataLoadTimeUnit(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -92,7 +92,7 @@ class CaptchaOperDataRes(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param OperDataLoadTimeUnitArray: 验证码加载耗时数据返回
 注意：此字段可能返回 null，表示取不到有效值。
         :type OperDataLoadTimeUnitArray: list of CaptchaOperDataLoadTimeUnit
@@ -142,7 +142,7 @@ class CaptchaOperDataRes(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -152,7 +152,7 @@ class CaptchaOperDataTryTimesDistributeUnit(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TryCount: 尝试次数
         :type TryCount: int
         :param UserCount: 用户请求数量
@@ -170,7 +170,7 @@ class CaptchaOperDataTryTimesDistributeUnit(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -180,7 +180,7 @@ class CaptchaOperDataTryTimesUnit(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DateKey: 时间
         :type DateKey: str
         :param CntPerPass: 平均尝试次数
@@ -202,7 +202,7 @@ class CaptchaOperDataTryTimesUnit(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -212,7 +212,7 @@ class CaptchaQueryData(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Cnt: 数量
         :type Cnt: int
         :param Date: 时间
@@ -230,7 +230,7 @@ class CaptchaQueryData(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -240,7 +240,7 @@ class CaptchaTicketDataRes(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TicketAmountArray: 票据验证总量返回
         :type TicketAmountArray: list of TicketAmountUnit
         :param TicketThroughArray: 票据验证通过量返回
@@ -277,7 +277,7 @@ class CaptchaTicketDataRes(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -287,7 +287,7 @@ class CaptchaUserAllAppId(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param AppName: 注册应用名称
@@ -313,7 +313,7 @@ class CaptchaUserAllAppId(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -323,7 +323,7 @@ class DescribeCaptchaAppIdInfoRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用注册APPID
         :type CaptchaAppId: int
         """
@@ -337,7 +337,7 @@ class DescribeCaptchaAppIdInfoRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -347,7 +347,7 @@ class DescribeCaptchaAppIdInfoResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SchemeColor: 界面风格
         :type SchemeColor: str
         :param Language: 语言
@@ -418,13 +418,6 @@ class DescribeCaptchaAppIdInfoResponse(AbstractModel):
         self.CaptchaCode = params.get("CaptchaCode")
         self.CaptchaMsg = params.get("CaptchaMsg")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeCaptchaDataRequest(AbstractModel):
@@ -433,7 +426,7 @@ class DescribeCaptchaDataRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param Start: 查询开始时间
@@ -459,7 +452,7 @@ class DescribeCaptchaDataRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -469,7 +462,7 @@ class DescribeCaptchaDataResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 返回码 0 成功 其它失败
         :type CaptchaCode: int
         :param Data: 数据数组
@@ -497,13 +490,6 @@ class DescribeCaptchaDataResponse(AbstractModel):
                 self.Data.append(obj)
         self.CaptchaMsg = params.get("CaptchaMsg")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeCaptchaDataSumRequest(AbstractModel):
@@ -512,7 +498,7 @@ class DescribeCaptchaDataSumRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param Start: 查询开始时间
@@ -534,7 +520,7 @@ class DescribeCaptchaDataSumRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -544,7 +530,7 @@ class DescribeCaptchaDataSumResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param GetSum: 请求总量
         :type GetSum: int
         :param VfySuccSum: 请求验证成功量
@@ -582,13 +568,6 @@ class DescribeCaptchaDataSumResponse(AbstractModel):
         self.CaptchaCode = params.get("CaptchaCode")
         self.CheckTicketSum = params.get("CheckTicketSum")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeCaptchaMiniDataRequest(AbstractModel):
@@ -597,7 +576,7 @@ class DescribeCaptchaMiniDataRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param Start: 查询开始时间 例如：2019112900
@@ -623,7 +602,7 @@ class DescribeCaptchaMiniDataRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -633,7 +612,7 @@ class DescribeCaptchaMiniDataResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 返回码 0 成功 其它失败
         :type CaptchaCode: int
         :param Data: 数据数组
@@ -661,13 +640,6 @@ class DescribeCaptchaMiniDataResponse(AbstractModel):
                 self.Data.append(obj)
         self.CaptchaMsg = params.get("CaptchaMsg")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeCaptchaMiniDataSumRequest(AbstractModel):
@@ -676,7 +648,7 @@ class DescribeCaptchaMiniDataSumRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param Start: 查询开始时间
@@ -698,7 +670,7 @@ class DescribeCaptchaMiniDataSumRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -708,7 +680,7 @@ class DescribeCaptchaMiniDataSumResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param GetSum: 请求总量
 注意：此字段可能返回 null，表示取不到有效值。
         :type GetSum: int
@@ -762,13 +734,6 @@ class DescribeCaptchaMiniDataSumResponse(AbstractModel):
         self.TicketThroughputSum = params.get("TicketThroughputSum")
         self.TicketInterceptSum = params.get("TicketInterceptSum")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeCaptchaMiniOperDataRequest(AbstractModel):
@@ -777,7 +742,7 @@ class DescribeCaptchaMiniOperDataRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param Start: 查询开始时间
@@ -799,7 +764,7 @@ class DescribeCaptchaMiniOperDataRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -809,7 +774,7 @@ class DescribeCaptchaMiniOperDataResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 成功返回 0 其它失败
         :type CaptchaCode: int
         :param CaptchaMsg: 返回信息
@@ -834,13 +799,6 @@ class DescribeCaptchaMiniOperDataResponse(AbstractModel):
             self.Data = CaptchaOperDataRes()
             self.Data._deserialize(params.get("Data"))
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeCaptchaMiniResultRequest(AbstractModel):
@@ -849,12 +807,12 @@ class DescribeCaptchaMiniResultRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaType: 固定填值：9（滑块验证码）
         :type CaptchaType: int
         :param Ticket: 验证码返回给用户的票据
         :type Ticket: str
-        :param UserIp: 透传业务侧获取到的验证码使用者的IP
+        :param UserIp: 业务侧获取到的验证码使用者的外网IP
         :type UserIp: str
         :param CaptchaAppId: 验证码应用APPID
         :type CaptchaAppId: int
@@ -895,7 +853,7 @@ class DescribeCaptchaMiniResultRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -905,7 +863,7 @@ class DescribeCaptchaMiniResultResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 1       ticket verification succeeded     票据验证成功
 7       CaptchaAppId does not match     票据与验证码应用APPID不匹配
 8       ticket expired     票据超时
@@ -931,13 +889,6 @@ class DescribeCaptchaMiniResultResponse(AbstractModel):
         self.CaptchaCode = params.get("CaptchaCode")
         self.CaptchaMsg = params.get("CaptchaMsg")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeCaptchaMiniRiskResultRequest(AbstractModel):
@@ -946,12 +897,12 @@ class DescribeCaptchaMiniRiskResultRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaType: 固定填值：9（滑块验证码）
         :type CaptchaType: int
         :param Ticket: 验证码返回给用户的票据
         :type Ticket: str
-        :param UserIp: 用户操作来源的外网 IP
+        :param UserIp: 业务侧获取到的验证码使用者的外网IP
         :type UserIp: str
         :param CaptchaAppId: 验证码应用APPID
         :type CaptchaAppId: int
@@ -1000,7 +951,7 @@ class DescribeCaptchaMiniRiskResultRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1010,7 +961,7 @@ class DescribeCaptchaMiniRiskResultResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 1 ticket verification succeeded 票据验证成功
 7 CaptchaAppId does not match 票据与验证码应用APPID不匹配
 8 ticket expired 票据超时
@@ -1046,13 +997,6 @@ class DescribeCaptchaMiniRiskResultResponse(AbstractModel):
             self.ManageMarketingRiskValue = OutputManageMarketingRiskValue()
             self.ManageMarketingRiskValue._deserialize(params.get("ManageMarketingRiskValue"))
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeCaptchaOperDataRequest(AbstractModel):
@@ -1061,7 +1005,7 @@ class DescribeCaptchaOperDataRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param Start: 查询开始时间
@@ -1083,7 +1027,7 @@ class DescribeCaptchaOperDataRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1093,7 +1037,7 @@ class DescribeCaptchaOperDataResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 成功返回 0 其它失败
         :type CaptchaCode: int
         :param CaptchaMsg: 返回信息
@@ -1118,13 +1062,6 @@ class DescribeCaptchaOperDataResponse(AbstractModel):
             self.Data = CaptchaOperDataRes()
             self.Data._deserialize(params.get("Data"))
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeCaptchaResultRequest(AbstractModel):
@@ -1133,12 +1070,12 @@ class DescribeCaptchaResultRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaType: 固定填值：9。可在控制台配置不同验证码类型。
         :type CaptchaType: int
         :param Ticket: 前端回调函数返回的用户验证票据
         :type Ticket: str
-        :param UserIp: 透传业务侧获取到的验证码使用者的IP
+        :param UserIp: 业务侧获取到的验证码使用者的外网IP
         :type UserIp: str
         :param Randstr: 前端回调函数返回的随机字符串
         :type Randstr: str
@@ -1187,7 +1124,7 @@ class DescribeCaptchaResultRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1197,7 +1134,7 @@ class DescribeCaptchaResultResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 1 OK 验证通过
 6 user code len error 验证码长度不匹配，请检查请求是否带Randstr参数，Randstr参数大小写是否有误
 7 captcha no match 验证码答案不匹配/Randstr参数不匹配，请重新生成Randstr、Ticket进行校验
@@ -1208,18 +1145,19 @@ class DescribeCaptchaResultResponse(AbstractModel):
 12 sig len error 签名长度错误
 13 verify ip no match ip不匹配，非法请求，可能存在不规范接入
 15 decrypt fail 验证码签名解密失败，票据校验失败，请检查Ticket票据是否与前端返回Ticket一致
-16 appid no match 验证码强校验appid错误，请检查CaptchaAppId是否为控制台基础配置界面系统分配的APPID
+16 appid no match 验证码强校验appid错误，前端代码 data-appid 和后端 CaptchaAppId 所填写的值，必须和 验证码控制台 中【验证详情】>【基础配置】内的 AppID 一致,请检查CaptchaAppId是否为控制台基础配置界面系统分配的APPID
 17 cmd no much 验证码系统命令不匹配
 18 uin no match 号码不匹配
 19 seq redirect 重定向验证
 20 opt no vcode 操作使用pt免验证码校验错误
-21 diff 差别，验证错误
+21 diff 差别，验证错误 
+该情况出现原因一般为，当验证码前端生成terror格式票据并进行后端票据校验时，用户网络较差，该情况下仍会返回可用票据，业务侧可以自行根据需要，进行票据生成或做其他处理。详情参见 [验证码Web前端接入-异常处理文档](https://cloud.tencent.com/document/product/1110/36841#.E5.BC.82.E5.B8.B8.E5.A4.84.E7.90.86)。
 22 captcha type not match 验证码类型与拉取时不一致
 23 verify type error 验证类型错误
 24 invalid pkg 非法请求包
 25 bad visitor 策略拦截
 26 system busy 系统内部错误
-100 param err appsecretkey 参数校验错误，请检查AppSecretKey是否与控制台基础配置界面系统分配的APPID、AppSecretKey相对应
+100 param err appsecretkey 参数校验错误，CaptchaAppId 与对应 AppSecretKey 不一致，需检查 AppSecretKey 参数是否有误。其中 CaptchaAppId、 AppSecretKey 在 验证码控制台 的【验证详情】>【基础配置】中获取
 104 Ticket Reuse 票据重复使用，同个票据验证多次，请重新生成Randstr、Ticket进行校验
         :type CaptchaCode: int
         :param CaptchaMsg: 状态描述及验证错误信息
@@ -1247,13 +1185,6 @@ class DescribeCaptchaResultResponse(AbstractModel):
         self.EvilLevel = params.get("EvilLevel")
         self.GetCaptchaTime = params.get("GetCaptchaTime")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeCaptchaTicketDataRequest(AbstractModel):
@@ -1262,7 +1193,7 @@ class DescribeCaptchaTicketDataRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param Start: 查询开始时间 例如：20200909
@@ -1280,7 +1211,7 @@ class DescribeCaptchaTicketDataRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1290,7 +1221,7 @@ class DescribeCaptchaTicketDataResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 成功返回 0 其它失败
         :type CaptchaCode: int
         :param CaptchaMsg: 返回信息
@@ -1315,13 +1246,6 @@ class DescribeCaptchaTicketDataResponse(AbstractModel):
             self.Data = CaptchaTicketDataRes()
             self.Data._deserialize(params.get("Data"))
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeCaptchaUserAllAppIdRequest(AbstractModel):
@@ -1336,7 +1260,7 @@ class DescribeCaptchaUserAllAppIdResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Data: 用户注册的所有Appid和应用名称
 注意：此字段可能返回 null，表示取不到有效值。
         :type Data: list of CaptchaUserAllAppId
@@ -1364,13 +1288,6 @@ class DescribeCaptchaUserAllAppIdResponse(AbstractModel):
         self.CaptchaCode = params.get("CaptchaCode")
         self.CaptchaMsg = params.get("CaptchaMsg")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class OutputManageMarketingRiskValue(AbstractModel):
@@ -1379,7 +1296,7 @@ class OutputManageMarketingRiskValue(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param UserId: 账号 ID。对应输入参数： AccountType 是 1 时，对应 QQ 的 OpenID。
 AccountType 是 2 时，对应微信的 OpenID/UnionID。
 AccountType 是 4 时，对应手机号。
@@ -1450,7 +1367,7 @@ reject：拒绝，高风险恶意
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1460,7 +1377,7 @@ class TicketAmountUnit(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DateKey: 时间
         :type DateKey: str
         :param Amount: 票据验证总量
@@ -1478,7 +1395,7 @@ class TicketAmountUnit(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1488,7 +1405,7 @@ class TicketInterceptUnit(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DateKey: 时间
         :type DateKey: str
         :param Intercept: 票据验证拦截量
@@ -1506,7 +1423,7 @@ class TicketInterceptUnit(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1516,7 +1433,7 @@ class TicketThroughUnit(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DateKey: 时间
         :type DateKey: str
         :param Through: 票据验证的通过量
@@ -1534,7 +1451,7 @@ class TicketThroughUnit(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1544,7 +1461,7 @@ class UpdateCaptchaAppIdInfoRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaAppId: 验证码应用ID
         :type CaptchaAppId: int
         :param AppName: 应用名
@@ -1606,7 +1523,7 @@ class UpdateCaptchaAppIdInfoRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1616,7 +1533,7 @@ class UpdateCaptchaAppIdInfoResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CaptchaCode: 返回码 0 成功，其它失败
         :type CaptchaCode: int
         :param CaptchaMsg: 返回操作信息
@@ -1633,11 +1550,4 @@ class UpdateCaptchaAppIdInfoResponse(AbstractModel):
     def _deserialize(self, params):
         self.CaptchaCode = params.get("CaptchaCode")
         self.CaptchaMsg = params.get("CaptchaMsg")
-        self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
\ No newline at end of file
+        self.RequestId = params.get("RequestId")
\ No newline at end of file
