@@ -86,6 +86,9 @@ OPERATIONDENIED_BANNEDAPPLICATION = 'OperationDenied.BannedApplication'
 # 没有API权限。
 OPERATIONDENIED_NOAPIAUTH = 'OperationDenied.NoApiAuth'
 
+# 未通过个人实名。
+OPERATIONDENIED_NOIDENTITYVERIFY = 'OperationDenied.NoIdentityVerify'
+
 # 用户与企业不对应。
 OPERATIONDENIED_USERNOTINORGANIZATION = 'OperationDenied.UserNotInOrganization'
 
